# Class163

#### 介绍
网易云音乐通用api库

#### 软件架构
软件架构说明


#### 安装教程

1.  `pip install class163`


#### 使用说明

1.  xxxx
2.  xxxx
3.  xxxx

#### 参与贡献

1.  Fork 本仓库
2.  新建 Feat_xxx 分支
3.  提交代码
4.  新建 Pull Request
